@@ -11,10 +11,13 @@
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
 
-"""qctrlqua - integration between BOULDER OPAL and QUA"""
+"""
+The Q-CTRL Python QUA package allows you to integrate BOULDER OPAL with the QUA
+quantum computing language.
+"""
 
 __author__ = "Q-CTRL <support@q-ctrl.com>"
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 
 from .qua_config_gen import (
     Pulse,
