@@ -37,26 +37,34 @@ def qctrl_pulse_to_samples(
     max_amplitude: float = 0.4,
 ) -> Tuple[List[float], List[float]]:
     """
-    Converts a pulse in Q-CTRL optimizer output in dictionary format into two lists that you can send to QUA config.
+    Converts a pulse in Q-CTRL optimizer output in dictionary format into
+    two lists that you can send to QUA config.
 
     Parameters
     ----------
     qctrl_pulse : list[dict]
-        A list of the numerical values of a pulse waveform. Each element is a dict which has two keys, `duration`
-        and `value`. The durations are in unit of seconds. The `value` can be complex, corresponding to I/Q value of the pulse.
+        A list of the numerical values of a pulse waveform. Each element is
+        a dict which has two keys, ``duration`` and ``value``. The
+        durations are in unit of seconds. The ``value`` can be complex,
+        corresponding to I/Q value of the pulse.
     rabi_to_amplitude_func : function, optional
-        A function mapping pulse amplitude into unitless numbers.
-        The function takes the form foo(x,y): tuple, accepting as input the I/Q values of the pulse in units of Hz, and returning as output the unitless
-        value of the I/Q.
+        A function mapping pulse amplitude into unitless numbers. The
+        function takes the form
+        ``func(x: float, y: float): tuple[float, float]``, accepting as
+        input the I/Q values of the pulse in units of Hz, and returning as
+        output the unitless value of the I/Q.
     max_amplitude : float, optional
-        The maximum pulse amplitude number of the system. The value should be between 0.1 and 0.49.
-        If no `rabi_to_amplitude_func` function is provided, or the output value goes beyond 0.49, the output values scaled to a maximum amplitude of
-        `max_amplitude` will be used. By default 0.4.
+        The maximum pulse amplitude number of the system. The value should
+        be between 0.1 and 0.49. If no `rabi_to_amplitude_func` function is
+        provided, or the output value goes beyond 0.49, the output values
+        scaled to a maximum amplitude of `max_amplitude` will be used. By
+        default 0.4.
 
     Returns
     -------
-    tuple[pulse_sample_I:list, pulse_sample_Q:list]
-        The lists of I/Q numerical values, in 1 nanosecond sample rate.
+    tuple[list, list]
+        The lists of I and Q numerical values (respectively), in 1
+        nanosecond sample rate.
     """
     if max_amplitude > 0.49 or max_amplitude < 0.1:
         raise ValueError("max_amplitude must be between 0.1 and 0.49.")
@@ -67,36 +75,36 @@ def qctrl_pulse_to_samples(
     )
     segments = np.pad(segments, (0, 4 - len(segments) % 4))
 
-    segment_I = np.real(segments)
-    segment_Q = np.imag(segments)
+    segment_i = np.real(segments)
+    segment_q = np.imag(segments)
     if rabi_to_amplitude_func is None:
-        max_I = np.max(np.abs(segment_I))
-        max_Q = np.max(np.abs(segment_Q))
-        max_input = max(max_I, max_Q)
+        max_i = np.max(np.abs(segment_i))
+        max_q = np.max(np.abs(segment_q))
+        max_input = max(max_i, max_q)
         scale_factor = max_input / max_amplitude
         rabi_to_amplitude_func = lambda x, y: (x / scale_factor, y / scale_factor)
 
-    pulse_sample_I, pulse_sample_Q = [], []
-    for input_I, input_Q in zip(segment_I, segment_Q):
-        output_I, output_Q = rabi_to_amplitude_func(input_I, input_Q)
-        pulse_sample_I.append(output_I)
-        pulse_sample_Q.append(output_Q)
+    pulse_sample_i, pulse_sample_q = [], []
+    for input_i, input_q in zip(segment_i, segment_q):
+        output_i, output_q = rabi_to_amplitude_func(input_i, input_q)
+        pulse_sample_i.append(output_i)
+        pulse_sample_q.append(output_q)
 
     # Check the input range
-    max_output_I = np.max(np.abs(pulse_sample_I))
-    max_output_Q = np.max(np.abs(pulse_sample_Q))
-    max_output = max(max_output_I, max_output_Q)
+    max_output_i = np.max(np.abs(pulse_sample_i))
+    max_output_q = np.max(np.abs(pulse_sample_q))
+    max_output = max(max_output_i, max_output_q)
     if max_output > max_amplitude:
         # Rescale is needed
         scale_factor = max_output / max_amplitude
-        new_pulse_sample_I, new_pulse_sample_Q = [], []
-        for input_I, input_Q in zip(pulse_sample_I, pulse_sample_Q):
-            output_I, output_Q = input_I / scale_factor, input_Q / scale_factor
-            new_pulse_sample_I.append(output_I)
-            new_pulse_sample_Q.append(output_Q)
-        pulse_sample_I, pulse_sample_Q = new_pulse_sample_I, new_pulse_sample_Q
+        new_pulse_sample_i, new_pulse_sample_q = [], []
+        for input_i, input_q in zip(pulse_sample_i, pulse_sample_q):
+            output_i, output_q = input_i / scale_factor, input_q / scale_factor
+            new_pulse_sample_i.append(output_i)
+            new_pulse_sample_q.append(output_q)
+        pulse_sample_i, pulse_sample_q = new_pulse_sample_i, new_pulse_sample_q
 
-    return pulse_sample_I, pulse_sample_Q
+    return pulse_sample_i, pulse_sample_q
 
 
 class _Qubit:
@@ -110,7 +118,8 @@ class _Qubit:
     name : str
         The name of the qubit.
     mixer_config : dict
-        The dictionary containing parameters of the mixer associated with the qubit.
+        The dictionary containing parameters of the mixer associated with
+        the qubit.
     mixer_name : str
         The name of the mixer, by default 'mxr_qb'
     """
@@ -165,18 +174,18 @@ def _integration_dictionary(
     integration_weight, pulse_length, rot_phase=-0.3, pad=0, integ_name="integW"
 ):
     w = integration_weight * np.ones(int(pulse_length // 4 + pad))
-    w_I = [np.cos(rot_phase) * w, -np.sin(rot_phase) * w]
-    w_Q = [np.sin(rot_phase) * w, np.cos(rot_phase) * w]
+    w_i = [np.cos(rot_phase) * w, -np.sin(rot_phase) * w]
+    w_q = [np.sin(rot_phase) * w, np.cos(rot_phase) * w]
     config = {
         integ_name
         + "_I": {
-            "cosine": w_I[0].tolist(),
-            "sine": w_I[1].tolist(),
+            "cosine": w_i[0].tolist(),
+            "sine": w_i[1].tolist(),
         },
         integ_name
         + "_Q": {
-            "cosine": w_Q[0].tolist(),
-            "sine": w_Q[1].tolist(),
+            "cosine": w_q[0].tolist(),
+            "sine": w_q[1].tolist(),
         },
     }
     return config
@@ -191,26 +200,41 @@ class Pulse:
     pulse_name : str
         A name to identify the pulse.
     sample : Any
-        The samples describing the waveform of the pulse. Takes three forms:
-        - tuple[float, int] : associate with constant pulse. The first number is the amplitude and the second number is the length of the pulse;
-        - list[float] : associate with time-dependent pulse. This will be set to `I` channel while `Q` channel will be set to zero.
-        tuple and ndarray can also be used.
-        - list[list[float], list[float]]: associate with time-dependent pulse with both I and Q channels. tuple and ndarray can also be used.
+        The samples describing the waveform of the pulse. Takes three
+        forms:
+
+          - tuple[float, int] : Associated with a constant pulse. The first
+            number is the amplitude and the second number is the length of
+            the pulse in nanoseconds.
+          - list[float] : Associated with a time-dependent pulse with only
+            an I channel. The values in the list give the samples of the I
+            channel (at a 1 nanosecond sample rate), and the Q channel is
+            set to zero. Tuples and NumPy arrays can be used instead of
+            lists.
+          - list[list[float], list[float]]: Associated with a
+            time-dependent pulse with both I and Q channels. The first
+            element in the outer list gives the samples of the I channel
+            and the second element gives the samples of the Q channel (both
+            at a 1 nanosecond sample rate). Tuples and NumPy arrays can be
+            used instead of lists.
+
     constant : bool, optional
-        To determine whether the pulse is constant or not. Defaulted to False.
+        To determine whether the pulse is constant or not. Defaulted to
+        False.
     pulse_type : str, optional
-        To determine whether the pulse is used to apply to a qubit or to a resonator.
-        Must be either 'control' or 'measurement'. Defaulted to 'control'.
+        To determine whether the pulse is used to apply to a qubit or to a
+        resonator.  Must be either 'control' or 'measurement'. Defaulted to
+        'control'.
     integration_weight : float, optional
         The integration weight used in demodulation. Defaulted to 4.0.
     integ_name : str, optional
-        The prefix string of the integration weights. Defaulted to 'integW'.
-
+        The prefix string of the integration weights. Defaulted to
+        'integW'.
     """
 
     def __init__(
         self,
-        pulse_name,
+        pulse_name: str,
         sample,
         constant=False,
         pulse_type="control",
@@ -218,22 +242,22 @@ class Pulse:
         integ_name="integW",
     ):
 
-        pulse_IQ = isinstance(sample, (list, np.ndarray, tuple)) and isinstance(
+        pulse_iq = isinstance(sample, (list, np.ndarray, tuple)) and isinstance(
             sample[0], (list, np.ndarray, tuple)
         )
         if constant:
             pulse_length = sample[1]
         else:
-            pulse_length = len(sample[0]) if pulse_IQ else len(sample)
+            pulse_length = len(sample[0]) if pulse_iq else len(sample)
 
-        if pulse_IQ:
-            waveform_I = _Waveform(pulse_name + "_I", sample[0])
-            waveform_Q = _Waveform(pulse_name + "_Q", sample[1])
+        if pulse_iq:
+            waveform_i = _Waveform(pulse_name + "_I", sample[0])
+            waveform_q = _Waveform(pulse_name + "_Q", sample[1])
         else:
-            waveform_I = _Waveform(pulse_name + "_wf", sample, constant=constant)
-            waveform_Q = _Waveform("wf_zero", (0.0, pulse_length), constant=True)
+            waveform_i = _Waveform(pulse_name + "_wf", sample, constant=constant)
+            waveform_q = _Waveform("wf_zero", (0.0, pulse_length), constant=True)
 
-        self.waveform = (waveform_I, waveform_Q)
+        self.waveform = (waveform_i, waveform_q)
         self.pulse_name = pulse_name
 
         if pulse_type not in ["control", "measurement"]:
@@ -247,8 +271,8 @@ class Pulse:
             "operation": operation,
             "length": pulse_length,
             "waveforms": {
-                "I": waveform_I.name,
-                "Q": waveform_Q.name,
+                "I": waveform_i.name,
+                "Q": waveform_q.name,
             },
         }
         if pulse_type == "measurement":
@@ -305,7 +329,8 @@ class _Resonator:
 class QmConfig:
     """
     Creates a QUA Config object that contains the config dict.
-    Based on the number of qubits, the first 2n control ports are used to interact with n qubits and the rest are connected to the resonators.
+    Based on the number of qubits, the first 2n control ports are used to
+    interact with n qubits and the rest are connected to the resonators.
 
     Parameters
     ----------
@@ -318,13 +343,18 @@ class QmConfig:
     resonator_intermediate_frequencies : list[float], optional
         The intermediate frequencies for each resonator, in Hz.
     qubit_names : list[str], optional
-        The name of each qubit. If no name is given, the default name of the first qubit is `qubit1`, and second qubit is `qubit2`, etc.
+        The name of each qubit. If no name is given, the default name of
+        the first qubit is ``qubit1``, and second qubit is ``qubit2``, and
+        so on.
     resonator_names : list[str], optional
-        The name of each resonator. If no name is given, the default name of the first resonator is `rr1`, and second resonator is `rr2`, etc.
+        The name of each resonator. If no name is given, the default name
+        of the first resonator is ``rr1``, and second resonator is ``rr2``,
+        and so on.
     drive_pulses : dict, optional
         The dictionary for pulses that will later be assigned to qubits.
     measurement_pulses : dict, optional
-        The dictionary for pulses that will later be assigned to resonators.
+        The dictionary for pulses that will later be assigned to
+        resonators.
     offsets : float, optional
         Offsets of the output signals. Defaulted to 0.1.
     version : int, optional
@@ -335,8 +365,8 @@ class QmConfig:
     Attributes
     ----------
     config: dict
-        The main config that contains all parameters of the Operator-X (OPX).
-
+        The main config that contains all parameters of the Operator-X
+        (OPX).
     """
 
     def __init__(
@@ -403,7 +433,7 @@ class QmConfig:
 
             mixer_name = "mxr_qb" + str(i + 1)
             element_name = qubit_names[i] if qubit_names else "qubit" + str(i + 1)
-            element = _Qubit(
+            element_qubit = _Qubit(
                 lo_f,
                 in_f,
                 controller=controller,
@@ -412,11 +442,11 @@ class QmConfig:
                 mixer_name=mixer_name,
             )
             for pulse_name in drive_pulses:
-                element._add_operation(pulse_name, pulse_name)
-            self.qubits.append(element)
+                element_qubit._add_operation(pulse_name, pulse_name)
+            self.qubits.append(element_qubit)
 
-            config["elements"][element_name] = element.config
-            config["mixers"][mixer_name] = element.mixer_config
+            config["elements"][element_name] = element_qubit.config
+            config["mixers"][mixer_name] = element_qubit.mixer_config
 
             channel = (channel[0] + 2, channel[1] + 2)
 
@@ -425,7 +455,7 @@ class QmConfig:
             in_f = resonator_intermediate_frequencies[i]
             mixer_name = "mxr_rr" + str(i + 1)
             element_name = resonator_names[i] if resonator_names else "rr" + str(i + 1)
-            element = _Resonator(
+            element_resonator = _Resonator(
                 lo_f,
                 in_f,
                 controller=controller,
@@ -434,11 +464,11 @@ class QmConfig:
                 mixer_name=mixer_name,
             )
             for pulse_name in measurement_pulses:
-                element._add_operation(pulse_name, pulse_name)
-            self.resonators.append(element)
+                element_resonator._add_operation(pulse_name, pulse_name)
+            self.resonators.append(element_resonator)
 
-            config["elements"][element_name] = element.config
-            config["mixers"][mixer_name] = element.mixer_config
+            config["elements"][element_name] = element_resonator.config
+            config["mixers"][mixer_name] = element_resonator.mixer_config
 
             channel = (channel[0] + 2, channel[1] + 2)
 
@@ -456,16 +486,17 @@ class QmConfig:
             The Pulse object.
         operation_name : str, optional
             The name of the operation corresponding to the pulse.
-            If no name is specified, the name of the pulse will be the operation name.
+            If no name is specified, the name of the pulse will be the
+            operation name.
         """
 
         pulse_name = pulse.pulse_name
         pulse_config = pulse.config
-        wf_I, wf_Q = pulse.waveform
+        wf_i, wf_q = pulse.waveform
 
         self.config["pulses"][pulse_name] = pulse_config
-        self.config["waveforms"][wf_I.name] = wf_I.config
-        self.config["waveforms"][wf_Q.name] = wf_Q.config
+        self.config["waveforms"][wf_i.name] = wf_i.config
+        self.config["waveforms"][wf_q.name] = wf_q.config
 
         qb = self.qubits[qubit_index]
 
@@ -486,16 +517,17 @@ class QmConfig:
             The Pulse object.
         operation_name : str, optional
             The name of the operation corresponding to the pulse.
-            If no name is specified, the name of the pulse will be the operation name.
+            If no name is specified, the name of the pulse will be the
+            operation name.
         """
 
         pulse_name = pulse.pulse_name
         pulse_config = pulse.config
-        wf_I, wf_Q = pulse.waveform
+        wf_i, wf_q = pulse.waveform
 
         self.config["pulses"][pulse_name] = pulse_config
-        self.config["waveforms"][wf_I.name] = wf_I.config
-        self.config["waveforms"][wf_Q.name] = wf_Q.config
+        self.config["waveforms"][wf_i.name] = wf_i.config
+        self.config["waveforms"][wf_q.name] = wf_q.config
 
         resonator = self.resonators[resonator_index]
 
